## 通达信板块成分

接口：tdx_member

描述：获取通达信各板块成分股信息

限量：单次最大3000条数据，可以根据日期和板块代码循环提取

权限：用户积累6000积分可调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 板块代码：xxxxxx.TDX |
| trade_date | str | N | 交易日期：格式YYYYMMDD |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 板块代码 |
| trade_date | str | Y | 交易日期 |
| con_code | str | Y | 成分股票代码 |
| con_name | str | Y | 成分股票名称 |

接口示例

```python
#获取东方财富2025年5月13日的航运概念板块成分股
df = pro.tdx_member(trade_date='20250513', ts_code='880728.TDX')
```

数据示例

```python
ts_code trade_date   con_code     con_name
0   880728.TDX   20250513  000039.SZ     中集集团
```